==> kubernetes-model-1.0.6-sources.jar: io/fabric8/kubernetes/api/model/ObjectFieldSelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ObjectFieldSelectorBuilder extends ObjectFieldSelectorFluent<ObjectFieldSelectorBuilder> implements VisitableBuilder<ObjectFieldSelector,ObjectFieldSelectorBuilder>{

     ObjectFieldSelectorFluent<?> fluent;
public ObjectFieldSelectorBuilder(){
    this(new ObjectFieldSelector());
}
public ObjectFieldSelectorBuilder( ObjectFieldSelectorFluent<?> fluent ){
    this(fluent, new ObjectFieldSelector());
}
public ObjectFieldSelectorBuilder( ObjectFieldSelectorFluent<?> fluent , ObjectFieldSelector instance ){
    this.fluent = fluent; fluent.withApiVersion(instance.getApiVersion()); fluent.withFieldPath(instance.getFieldPath()); 
}
public ObjectFieldSelectorBuilder( ObjectFieldSelector instance ){
    this.fluent = this; this.withApiVersion(instance.getApiVersion()); this.withFieldPath(instance.getFieldPath()); 
}

public EditableObjectFieldSelector build(){
    EditableObjectFieldSelector buildable = new EditableObjectFieldSelector(fluent.getApiVersion(),fluent.getFieldPath());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.17-sources.jar: io/fabric8/kubernetes/api/model/ObjectFieldSelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class ObjectFieldSelectorBuilder extends ObjectFieldSelectorFluent<ObjectFieldSelectorBuilder> implements VisitableBuilder<ObjectFieldSelector,ObjectFieldSelectorBuilder>{

     ObjectFieldSelectorFluent<?> fluent;
public ObjectFieldSelectorBuilder(){
    this(new ObjectFieldSelector());
}
public ObjectFieldSelectorBuilder( ObjectFieldSelectorFluent<?> fluent ){
    this(fluent, new ObjectFieldSelector());
}
public ObjectFieldSelectorBuilder( ObjectFieldSelectorFluent<?> fluent , ObjectFieldSelector instance ){
    this.fluent = fluent; fluent.withApiVersion(instance.getApiVersion()); fluent.withFieldPath(instance.getFieldPath()); 
}
public ObjectFieldSelectorBuilder( ObjectFieldSelector instance ){
    this.fluent = this; this.withApiVersion(instance.getApiVersion()); this.withFieldPath(instance.getFieldPath()); 
}

public EditableObjectFieldSelector build(){
    EditableObjectFieldSelector buildable = new EditableObjectFieldSelector(fluent.getApiVersion(),fluent.getFieldPath());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ObjectFieldSelectorBuilder that = (ObjectFieldSelectorBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
